Input and Output
================

.. https://docs.scipy.org/doc/numpy/reference/routines.io.html

NumPy binary files (NPY, NPZ)
-----------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.load
   cupy.save
   cupy.savez
   cupy.savez_compressed


String formatting
-----------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.array_repr
   cupy.array_str


Base-n representations
----------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.binary_repr
   cupy.base_repr
